
Changelog
=========

1.0.0 (2024-04-12)
------------------

* Dropped support for old Pythons. Minium supported version is 3.8.
* Improved error handling and reporting.
* Increased compatibility with `gosu <https://github.com/tianon/gosu>`_.

0.2.0 (2016-05-06)
------------------

* Allow using ":group" as argument, just like ``gosu`` (it will use the current user, but with the given group).

0.1.0 (2016-04-19)
------------------

* First release on PyPI.
